## Tests

Note that most of the tests in `redflag` are doctests. The testing code is in the docstrings of the various functions, under the 'examples' heading.

The Jupyter Notebooks in `docs/notebooks` are also run as part of the tests.

To run the tests: clone the repo, install the dev dependencies (e.g. with `pip install .[dev]`) and do:

    pytest
